\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{haid}[HAID paper template]

\LoadClass[twocolumn,10pt]{article}
\DeclareOption{onecolumn}{\OptionNotUsed}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax

% Colors
\RequirePackage{xcolor}
\definecolor{haidred}{HTML}{992222}
\newcommand{\setred}{\color{haidred}}
\definecolor{gray75}{gray}{0.75}
\definecolor{gray90}{gray}{0.90}

% Fonts, encoding and language
\usepackage[sfdefault,condensed]{roboto}

\usepackage[T1]{fontenc}
\usepackage[utf8]{inputenc}
\usepackage[english]{babel}

% Paper size and margins
\usepackage[letterpaper]{geometry}
\geometry{
  letterpaper,
  textwidth=18cm,
  hmarginratio=1:1,
  textheight=23cm,
  vmarginratio=1:1,
  heightrounded
}
\setlength{\headheight}{17pt}

\usepackage{balance}

% Author part
\usepackage{authblk}
\setcounter{Maxaffil}{10}
\renewcommand\Authands{, }
\renewcommand\Authfont{\scshape}
\renewcommand\Affilfont{\itshape\small}
\date{}

% headers
\usepackage{fancyhdr}
\pagestyle{fancy}
\lhead{}
\cfoot{}
\rhead{\textbf{HAID 2019, Lille, France}}
\renewcommand{\headrule}{
  \setlength\@tempdima{\headrulewidth}
  \textcolor{haidred}{\hrule\@height\@tempdima\@width\headwidth}
  \vskip -2\@tempdima
}

% Copyright statement only of first page
\fancypagestyle{plain}
{
  \lfoot{Copyright is held by authors}
}


% section styles
\usepackage[nobottomtitles*]{titlesec}
\renewcommand{\bottomtitlespace}{20mm}
\titleformat{\section}
   {\normalfont\large\scshape\bfseries}% format
   {}% label
   {1em}% sep
   {}% before code
   [{\color{haidred}\titlerule[0.4pt]}]% after code

\titlespacing{\section}
   {0pt}% left
   {10pt plus 2pt minus 2pt}% before sep
   {\baselineskip}% after sep

\titleformat{\subsection}
   {\normalfont\normalsize\scshape\bfseries\color{haidred}}% format
   {}% label
   {1em}% sep
   {}% before code
   []% after code

\titlespacing{\subsection}
   {0pt}% left
   {6pt plus 2pt minus 2pt}% before sep
   {4pt plus 2pt minus 2pt}% after sep

\titleformat{\paragraph}[runin]
   {\normalfont\normalsize\itshape\color{haidred}}% format
   {}% label
   {1em}% sep
   {}% before code
   []% after code

\let\subsubsection\undefined

\usepackage{mdframed}

% Figure captions
\usepackage[format=plain,
            labelfont=it,
            textfont=it]{caption}
 
% Abstract
\renewenvironment{abstract}{%
  \begin{mdframed}[backgroundcolor=gray90, linewidth=0pt]\itshape%
}{%
  \end{mdframed}%
}

% text parameters
\renewcommand{\normalsize}{\fontsize{9}{10}\selectfont}
\setcounter{secnumdepth}{0}
\setlength{\parskip}{3pt}
\setlength{\parindent}{0pt}

\widowpenalty=10000
\clubpenalty=10000

% useful draft commands
\newcommand{\noimage}{%
  \setlength{\fboxsep}{-\fboxrule}%
  \fbox{\phantom{\rule{150pt}{100pt}}}% Framed box
}

\newcommand{\loremipsum}{\textcolor{gray75}{Lorem ipsum dolor sit amet, consectetur adipiscing elit. Quisque scelerisque porta diam. Suspendisse vel metus sit amet dui mollis lacinia vel a urna. In pretium ante tristique urna accumsan, iaculis consectetur eros iaculis. Suspendisse sit amet mi libero. Maecenas odio arcu, dignissim id porta tristique, porttitor in orci. Proin ex nibh, efficitur quis gravida eget, fringilla in metus. Pellentesque velit tortor, luctus eget erat at, feugiat feugiat quam. Fusce a enim quam. Donec porta volutpat purus vel fringilla. Aenean et maximus lorem. Praesent feugiat semper consectetur. Integer magna est, semper et ullamcorper at, elementum sed erat. Cras tristique ullamcorper est, suscipit ornare metus convallis vel.}}